# PeakViz
This repository represents a simple workflow to visualize Hyperspectral data from point sensors: PSR and Fourier Transform Infrared Spectroscopy (FTIR) sensor. The wavelength ranges for these sensors are :
- PSR : 350.0 - 2500.0 nm
- FTIR : 2500.0629 - 15385.6915 nm

<p align="center">
  <img src="image1.png" width="500"/>
</p>

# Tutorial
Coming soon ...

# Acknowledgement
This work is performed at [Helmholtz Institute Freiberg for Resource Technology](https://www.hzdr.de/db/Cms?pOid=32948&pNid=2423&pLang=en) in the [Exploration](https://www.iexplo.space/) department



